"""Version information."""
__title__ = "chicken_dinner"
__description__ = "PUBG JSON API wrapper and playback visualizer."
__url__ = "https://github.com/crflynn/chicken-dinner"
__version__ = "0.2.4"
__author__ = "Christopher Flynn"
__author_email__ = "crf204@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2018 Christopher Flynn"
__docs_copyright__ = "2018 Christopher Flynn"
